# About the C++ interface

The C++ interface to an output database is related closely to the Abaqus Scripting Interface. Disparities between the two interfaces are due to fundamental differences in the programming languages. The C++ interface is intended for users with high-performance requirements; others are encouraged to use the Abaqus Scripting Interface.

A working knowledge of the C++ programming language is assumed.
